@@ -109,6 +109,13 @@ class TextAnalysisAnswer(object):
         :returns: A list of Entity objects
         """
         return self.__entities.values()
+        
+    def getAllEntitiesDict(self):
+        """
+        Returns the entities dictionary found in the input text.
+        :returns: A dictionary of Entity objects
+        """
+        return self.__entities
 
     def getAllSentences(self):
         """
@@ -117,6 +124,13 @@ class TextAnalysisAnswer(object):
         """
         return self.__sentences.values()
 
+    def getAllSentencesDict(self):
+        """
+        Returns the sentence parts dictionary found in the input text.
+        :returns: A dictionary of Sentence objects
+        """
+        return self.__sentences
+
     def getFullHTMLText(self, wrapSentencePartsWithSynonymHitsInSpans = False):
         """
         Returns an HTML enriched text with html spans around the recognized entities, phrases and synonyms.
